﻿Option Explicit On

Imports XSP
Imports XCM
Imports System.Windows.Forms
Imports System.IO
Imports System.Runtime.ConstrainedExecution
Imports System.Data
''' ---------------------------------------------
''' <summary>
''' バーコードラベルReport出力クラス
''' </summary>
''' <remarks>
''' Copyright 2010 FUJITSU SHIKOKU SYSTEMS LIMITED All rights reserved.<BR/>
''' FUJITSU SHIKOKU SYSTEMS LIMITED CONFIDENTIAL<BR/>
''' </remarks>
''' ---------------------------------------------
Public NotInheritable Class BCP010R010

#Region "解放処理"
	'確実な解放処理を実行するために指定
	Inherits CriticalFinalizerObject
	'解放処理を実装する為に指定
	Implements IDisposable

	''' ---------------------------------------------
	''' <summary>
	''' Dispose（解放処理）※外からはよばない
	''' </summary>
	''' <param name="disposing"></param>
	''' <remarks>
	''' 2010/10/04 新規作成 ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overloads Sub Dispose(ByVal disposing As Boolean)
		If disposing Then
			_pValueFrm = Nothing						'フォーム
			_pValuePrint = Nothing						'印刷フラグ
			_pValueType = Nothing						'表示単位
			_pValueDgv = Nothing						'一覧
			_pValueKuhaku = Nothing						'空白
			_pValueBusu = Nothing						'部数
			_pValuePatirntNo = Nothing					'患者番号
			_pValueHspHistryNo = Nothing				'入退院歴番号
			_pValueCliHistryNo = Nothing				'科歴番号
		End If
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' Finalize（解放処理）
	''' </summary>
	''' <remarks>
	''' 2010/10/04 新規作成 ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Overloads Sub Dispose() Implements IDisposable.Dispose
		Dispose(True)
		MyBase.Finalize()
		GC.SuppressFinalize(Me)
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' Finalize（解放処理）※外からはよばない
	''' </summary>
	''' <remarks>
	''' 2010/10/04 新規作成 ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Protected Overrides Sub Finalize()
		Dispose(False)
		MyBase.Finalize()
	End Sub
#End Region

#Region "変数"
	'IN項目
	Private _pValueFrm As frmBase = Nothing									'フォーム
	Private _pValuePrint As Boolean											'印刷フラグ
	Private _pValueType As clsConst.Enum_LendUnit = Nothing					'表示単位
	Private _pValueDgv As New DataGridView									'一覧
	Private _pValueKuhaku As Integer = Nothing								'空白
	Private _pValueBusu As Integer = Nothing								'部数
	Private _pValuePatirntNo As String = Nothing							'患者番号
	Private _pValueHspHistryNo As Integer = Nothing							'入退院歴番号
	Private _pValueCliHistryNo As Integer = Nothing							'科歴番号
#End Region

#Region "コンスタント"
	Private Const CST_LOG_PRODUCT As String = ""							'ログ記述用コンスト変数
	Private Const CST_LOG_CLASS As String = "バーコードラベル（Report）"		'ログ記述用コンスト変数
	Private Const CST_BC_CAR As String = "a"								'バーコード前後付加文字
	Private Const CST_BARCODE_PATIENT_NO As String = "I"					'バーコード印字内容：患者番号
	Private Const CST_BARCODE_DEPT_CD As String = "K"						'バーコード印字内容：診療科コード
	Private Const CST_BARCODE_DATE As String = "D"							'バーコード印字内容：日付

	Private Const CST_START_DT_FLG As String = "N"							'バーコード文字編集用（入院日）
	Private Const CST_END_DT_FLG As String = "T"							'バーコード文字編集用（退院日）



#End Region

#Region "コンストラクタ"

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' ※BCP010F010から呼び出されたとき
	''' </summary>
	''' <param name="pForm">frmBase</param>
	''' <param name="pValuePrint">印刷フラグ</param>
	''' <param name="pShowType">表示単位</param>
	''' <param name="pData">一覧</param>
	''' <param name="pKuhaku">空白</param>
	''' <param name="pBusu">部数</param>			
	''' <remarks>
	''' 2010/10/05 新規作成 ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New(ByVal pForm As Form, ByVal pValuePrint As Boolean, ByVal pShowType As clsConst.Enum_LendUnit, ByVal pData As DataGridView, ByVal pKuhaku As Integer, ByVal pBusu As Integer)
		_pValueFrm = pForm
		_pValuePrint = pValuePrint
		_pValueType = pShowType
		_pValueDgv = pData
		_pValueKuhaku = pKuhaku
		_pValueBusu = pBusu
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' ※BCP010F010以外から呼び出されたとき（患者単位）
	''' </summary>
	''' <param name="pForm">frmBase</param>
	''' <param name="pValuePrint">印刷フラグ</param>
	''' <param name="pPatirntNo">患者番号</param>
	''' <remarks>
	''' 2010/10/05 新規作成 ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New(ByVal pForm As Form, ByVal pValuePrint As Boolean, ByVal pPatirntNo As String)
		_pValueFrm = pForm
		_pValuePrint = pValuePrint
		_pValuePatirntNo = pPatirntNo
		_pValueHspHistryNo = 0
		_pValueCliHistryNo = 0
		_pValueType = clsConst.Enum_LendUnit.Each_Patient
		_pValueKuhaku = 0
		_pValueBusu = 1
		_pValueDgv = Nothing
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' ※BCP010F010以外から呼び出されたとき（入退院歴単位）
	''' </summary>
	''' <param name="pForm">frmBase</param>
	''' <param name="pValuePrint">印刷フラグ</param>
	''' <param name="pPatirntNo">患者番号</param>	
	''' <param name="pHspHistryNo">入退院歴番号</param>	
	''' <remarks>
	''' 2010/10/05 新規作成 ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New(ByVal pForm As Form, ByVal pValuePrint As Boolean, ByVal pPatirntNo As String, ByVal pHspHistryNo As Integer)
		_pValueFrm = pForm
		_pValuePrint = pValuePrint
		_pValuePatirntNo = pPatirntNo
		_pValueHspHistryNo = pHspHistryNo
		_pValueCliHistryNo = 0
		_pValueType = clsConst.Enum_LendUnit.Each_Hosp
		_pValueKuhaku = 0
		_pValueBusu = 1
		_pValueDgv = Nothing
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' コンストラクタ
	''' ※BCP010F010以外から呼び出されたとき（科歴単位）
	''' </summary>
	''' <param name="pForm">frmBase</param>
	''' <param name="pValuePrint">印刷フラグ</param>
	''' <param name="pPatirntNo">患者番号</param>	
	''' <param name="pHspHistryNo">入退院歴番号</param>	
	''' <param name="pCliHistryNo">科歴番号</param>	
	''' <remarks>
	''' 2010/10/05 新規作成 ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Sub New(ByVal pForm As Form, ByVal pValuePrint As Boolean, ByVal pPatirntNo As String, ByVal pHspHistryNo As Integer, ByVal pCliHistryNo As Integer)
		_pValueFrm = pForm
		_pValuePrint = pValuePrint
		_pValuePatirntNo = pPatirntNo
		_pValueHspHistryNo = pHspHistryNo
		_pValueCliHistryNo = pCliHistryNo
		_pValueType = clsConst.Enum_LendUnit.Each_Dept
		_pValueKuhaku = 0
		_pValueBusu = 1
		_pValueDgv = Nothing
	End Sub
#End Region

#Region "メソッド"

	''' ---------------------------------------------
	''' <summary>
	''' 印刷・プレビュー処理
	''' </summary>	
	''' <remarks>
	''' 2010/10/05 新規作成 ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Public Function exeReport() As Boolean
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "exeReport", CST_LOG_PRODUCT, CST_LOG_CLASS, "印刷・プレビュー処理 START")
		Dim pMeiNo As Integer = 1										'明細番号
		Dim pDataRow As DataRow = Nothing								'取得データ１行分
		Dim FilePath As String = Nothing								'mdbファイルパス
		Dim cliAccess As clsXTM_PRINTSETTING_ACCESS						'印刷設定情報クラス
		Dim datAccess As datXTM_PRINTSETTING_ACCESS_OneRec = Nothing	'印刷設定情報１件分
		Dim cliCom As clsCom											'共通メソッドクラス
		Try
			cliAccess = New clsXTM_PRINTSETTING_ACCESS
			cliCom = New clsCom
			' 印刷設定情報取得
			datAccess = cliAccess.getAccessSettingOneRec(Me._pValueFrm.Name, Me.GetType.Name)
			If datAccess Is Nothing Then
				Return False
			End If
			'MDBのパスを取得
			FilePath = cliCom.setReportPath(datAccess.FILE_NM)
			Using cliReportFunc As New clsReportFunc(Me._pValueFrm, FilePath, datAccess.REPORT_NM, Me._pValuePrint)
				' ＤＢ更新処理
				Using db As New clsDB(clsSysMst.ctlConfigData)
					'ワークテーブルの削除
					cliReportFunc.exeHeaderDel(db, Me.GetType.Name, True)
					cliReportFunc.exeWorkDel(db, Me.GetType.Name, sqlBCP010R010.sqlDel_Data, sqlBCP010R010.prmPRT_ID, sqlBCP010R010.prmHOST_NM)
					'ヘッダーワークテーブルの追加
					cliReportFunc.exeHeaderIns(db, Me.getHeaderData, True)
					'ワークテーブル更新処理
					If setWorkData(db) = False Then Return False
				End Using
				' ﾌﾟﾚﾋﾞｭｰ・印刷処理
				If cliReportFunc.AcPrint(datAccess.NUMBERPRINTED) = False Then
					Return False
				End If
			End Using

			Return True
		Catch ex As Exception
			Throw
		Finally
			pMeiNo = Nothing
			pDataRow = Nothing
			cliAccess = Nothing
			datAccess = Nothing
			cliCom = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ヘッダーデータ編集
	''' </summary>
	''' <returns>ヘッダーデータ</returns>
	''' <remarks>
	''' 2010/10/05 新規作成 ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getHeaderData() As datHeader
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "getHeaderData", CST_LOG_PRODUCT, CST_LOG_CLASS, "ヘッダーデータ取得 START")
		Dim retHeader As datHeader
		Try
			retHeader = New datHeader
			With retHeader
				.PRT_ID = Me.GetType.Name					'帳票ID	
			End With
			Return retHeader
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' ワークデータ作成処理
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <returns>True:成功 False:失敗</returns>
	''' <remarks>
	''' 2010/10/05 新規作成 ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function setWorkData(ByVal db As clsDB) As Boolean
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "setWorkData", CST_LOG_PRODUCT, CST_LOG_CLASS, "ワークテーブル更新 START")
		Dim pMeiNo As Integer = 1									'明細番号
		Dim pDataRow As DataRow = Nothing							'取得データ１行分
		Dim datHedder As datHeader = Nothing						'ヘッダー情報クラス
		Dim dtData As DataTable = Nothing							'抽出データ(BC印刷画面以外からの呼出時に使用)
		Dim row As DataRow
		Try

			With db
				'　バーコード印刷画面(BCP010F010)以外から呼び出されたときはDGVにデータが存在しないため、テーブルからデータを取得しDGV変数にセットする。
				If Me._pValueDgv Is Nothing Then
					dtData = Me.getData(db)
				End If
				' ＳＱＬ文セット
				.setSQL(sqlBCP010R010.sqlIns_Data)
				' パラメータデータ型セット
				Me.setSqlParm(db)
				' 空白の数だけ空白行を作成
				'空白行作成
				For i As Integer = 1 To Me._pValueKuhaku
					.setVal(sqlBCP010R010.prmDSPORDER, pMeiNo)		'表示順パラメータ値セット
					.execNonQuery(True)								'INSERT文実行
					pMeiNo += 1										'明細No加算
				Next i
				' データを１行ずつワークテーブルに追加
				'１行ずつデータをワークテーブルに追加する
				If Me._pValueDgv Is Nothing Then
					For Each pRow As DataRow In dtData.Rows
						'部数分だけ同じデータをワークテーブルに追加する。
						For i As Integer = 1 To Me._pValueBusu
							Me.setParm(db, pRow, pMeiNo)			'パラメータセット
							.execNonQuery(True)						'INSERT文実行
							pMeiNo += 1								'明細No加算
						Next i
					Next
				Else
					For Each pRow As DataGridViewRow In Me._pValueDgv.Rows
						row = CType(pRow.DataBoundItem, DataRowView).Row
						'チェック＝ONもののみ出力
						If row(sqlBCP010R010.itmSELECTED).ToString = CStr(clsConst.Enum_CheckBox_Flg.CheckOn) Then
							'部数分だけ同じデータをワークテーブルに追加する。
							For i As Integer = 1 To Me._pValueBusu
								Me.setParm(db, row, pMeiNo)			'パラメータセット
								.execNonQuery(True)						'INSERT文実行
								pMeiNo += 1								'明細No加算
							Next i
						End If
					Next
				End If
			End With
			Return True
		Catch ex As Exception
			Throw
		Finally
			dtData = Nothing
			datHedder = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' データ取得
	''' </summary>
	''' <param name="db">クラスMDB</param>
	''' <returns>取得データテーブル</returns>
	''' <remarks>
	''' 2010/10/20 新規作成 ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function getData(ByVal db As clsDB) As DataTable
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "getData", CST_LOG_PRODUCT, CST_LOG_CLASS, "データ取得 START")
		Dim dtData As DataTable
		Try
			dtData = New DataTable
			With db
				'SQL文セット
				Select Case Me._pValueType
					Case clsConst.Enum_LendUnit.Each_Patient	 '患者単位
						.setSQLDa(sqlBCP010R010.sqlSel_Patirnt)
					Case clsConst.Enum_LendUnit.Each_Hosp		 '入退院単位
						.setSQLDa(sqlBCP010R010.sqlSel_HspHistry)
						'パラメータ
						.setParamDa(sqlBCP010R010.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbNVarChar)	  '入退院歴番号
						.setValDa(sqlBCP010R010.prmHSP_HISTORY_NO, Me._pValueHspHistryNo)
					Case clsConst.Enum_LendUnit.Each_Dept		 '科歴単位
						.setSQLDa(sqlBCP010R010.sqlSel_CliHistry)
						'パラメータ
						.setParamDa(sqlBCP010R010.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbNVarChar)	  '入退院歴番号
						.setParamDa(sqlBCP010R010.prmCH_NO, clsDB.Enum_dbType.dbNVarChar)				  '科歴番号
						.setValDa(sqlBCP010R010.prmHSP_HISTORY_NO, Me._pValueHspHistryNo)
						.setValDa(sqlBCP010R010.prmCH_NO, Me._pValueCliHistryNo)
				End Select
				'共通パラメータ
				.setParamDa(sqlBCP010R010.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)	  '患者番号
				.setValDa(sqlBCP010R010.prmPATIENT_NO, Me._pValuePatirntNo)
				.setParamDa(sqlBCP010R010.prmLENDITEM_CD, clsDB.Enum_dbType.dbNVarChar)	  '管理物コード
				.setValDa(sqlBCP010R010.prmLENDITEM_CD, clsConst.Enum_Lenditem.MedicalRecord)
				.setParamDa(sqlBCP010R010.prmSELECTED, clsDB.Enum_dbType.dbInt)			  '選択チェック
				.setValDa(sqlBCP010R010.prmSELECTED, CType(clsConst.Enum_CheckBox_Flg.CheckOn, String))
				'データ取得
				.execQueryDa(dtData)
			End With
			Return dtData
		Catch ex As Exception
			Throw
		Finally
			dtData = Nothing
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' パラメータデータ型設定
	''' </summary>
	''' <param name="db">クラスMDB</param>
	''' <remarks>
	''' 2010/10/05 新規作成 ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub setSqlParm(ByVal db As clsDB)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "setSqlParm", CST_LOG_PRODUCT, CST_LOG_CLASS, "パラメータデータ型セット START")
		Try
			With db
				' パラメータデータ型設定
				.setParam(sqlBCP010R010.prmHOST_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmPATIENT_ID_V3, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmPATIENT_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmPATIENT_KNM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmDEPT_CD, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmDEPT_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmGENDER_CD, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmBYOREKI_NO, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmHSP_DT, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmOUT_HSP_DT, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmREMARKS1, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmREMARKS2, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmBARCODE, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmCHECK_FLG, clsDB.Enum_dbType.dbInt)
				.setParam(sqlBCP010R010.prmPATIENT_NO, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmHSP_HISTORY_NO, clsDB.Enum_dbType.dbInt)
				.setParam(sqlBCP010R010.prmCH_NO, clsDB.Enum_dbType.dbInt)
				.setParam(sqlBCP010R010.prmWARD_CD, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmWARD_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmHSP_CNL_CD, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmHSP_CNL_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmOUT_HSP_CNL_CD, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmOUT_HSP_CNL_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmOUT_HSP_OUTCOME_CD, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmOUT_HSP_OUTCOME_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmRECORD_MNGSTATUS_CD, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmMNGSTATUS_NM, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmDSPORDER, clsDB.Enum_dbType.dbInt)
				.setParam(sqlBCP010R010.prmLASTUPDUSER_CD, clsDB.Enum_dbType.dbNVarChar)
				.setParam(sqlBCP010R010.prmLASTUPD_DT, clsDB.Enum_dbType.dbDateTime)
			End With
			' パラメータ値設定(一旦すべてNullをセット)
			Me.setParm_Space(db)
		Catch ex As Exception
			Throw
		End Try

	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パラメータセット
	''' </summary>
	''' <param name="db">clsDB</param>
	''' <param name="pRow">１レコードデータ</param>
	''' <param name="MeiNo">表示順</param>
	''' <remarks>
	''' 2010/10/05 新規作成 ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub setParm(ByVal db As clsDB, ByVal pRow As DataRow, ByVal MeiNo As Integer)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "setParm", CST_LOG_PRODUCT, CST_LOG_CLASS, "MDB登録パラメータセット START")
		Dim wrkBARCODE As String = Nothing		   'バーコード編集用
		Dim wrkBarcodeType As String = Nothing		'バーコード印刷文字
		Dim wrkDate As String = Nothing				'日付形式編集用
		Dim wPATIENT_NO As String = Nothing
		Try
			wPATIENT_NO = pRow(sqlBCP010R010.itmPATIENT_NO).ToString
			With db
				' 共通パラメータ値設定
				.setVal(sqlBCP010R010.prmPATIENT_ID_V3, wPATIENT_NO)												'患者番号
				.setVal(sqlBCP010R010.prmPATIENT_NM, pRow(sqlBCP010R010.itmPATIENT_NM).ToString)					'氏名
				.setVal(sqlBCP010R010.prmDSPORDER, MeiNo)															'表示順
				' 表示単位ごとのパラメータ値設定
				Select Case Me._pValueType
					Case clsConst.Enum_LendUnit.Each_Patient	  '患者単位
						'バーコード文字編集
						wrkBARCODE = CST_BC_CAR & Me.cnvPatientNo(pRow(sqlBCP010R010.itmPATIENT_NO).ToString) & CST_BC_CAR
						.setVal(sqlBCP010R010.prmBARCODE, wrkBARCODE)												'バーコード
						.setVal(sqlBCP010R010.prmCHECK_FLG, clsConst.Enum_CheckBox_Flg.CheckOn)						'チェック											
						.setVal(sqlBCP010R010.prmPATIENT_NO, pRow(sqlBCP010R010.itmPATIENT_NO).ToString)			'患者番号
						.setVal(sqlBCP010R010.prmMNGSTATUS_NM, pRow(sqlBCP010R010.itmMNGSTATUS_NM).ToString)		'管理状況
					Case clsConst.Enum_LendUnit.Each_Hosp		  '入退院歴単位
						.setVal(sqlBCP010R010.prmDEPT_CD, pRow(sqlBCP010R010.itmDEPT_CD).ToString)					'診療科コード
						.setVal(sqlBCP010R010.prmDEPT_NM, pRow(sqlBCP010R010.itmDEPT_RNM).ToString)					'診療科名
						.setVal(sqlBCP010R010.prmBYOREKI_NO, pRow(sqlBCP010R010.itmBYOREKI_NO).ToString)			'病歴番号
						.setVal(sqlBCP010R010.prmHSP_DT, chkDbDate(pRow(sqlBCP010R010.itmHSP_DT).ToString))			'入院日
						.setVal(sqlBCP010R010.prmOUT_HSP_DT, chkDbDate(pRow(sqlBCP010R010.itmOUT_HSP_DT).ToString))	'退院日

						wrkBarcodeType = clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00092)
						For i As Integer = 0 To wrkBarcodeType.Length - 1
							Select Case wrkBarcodeType.Chars(i)
							Case CST_BARCODE_PATIENT_NO																'患者番号
														wrkBARCODE &= Me.cnvPatientNo(pRow(sqlBCP010R010.itmPATIENT_NO).ToString)
							Case CST_BARCODE_DEPT_CD																'診療科コード
														wrkBARCODE &= pRow(sqlBCP010R010.itmDEPT_CD).ToString
							Case CST_BARCODE_DATE
											Select Case clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00077)
												Case CST_START_DT_FLG	'入院日
													If IsDate(pRow(sqlBCP010R010.itmHSP_DT)) = True Then
														wrkBARCODE &= FormatDateTime(pRow(sqlBCP010R010.itmHSP_DT), DateFormat.ShortDate).Replace("/", "")
													End If
												Case CST_END_DT_FLG		'退院日
													If IsDate(pRow(sqlBCP010R010.itmOUT_HSP_DT)) = True Then
														wrkBARCODE &= FormatDateTime(pRow(sqlBCP010R010.itmOUT_HSP_DT), DateFormat.ShortDate).Replace("/", "")
													End If
												Case Else

											End Select
							Case Else

							End Select
						Next
						.setVal(sqlBCP010R010.prmBARCODE, CST_BC_CAR & wrkBARCODE & CST_BC_CAR)						'バーコード
						.setVal(sqlBCP010R010.prmCHECK_FLG, clsConst.Enum_CheckBox_Flg.CheckOn)						'チェック							
						.setVal(sqlBCP010R010.prmPATIENT_NO, pRow(sqlBCP010R010.itmPATIENT_NO).ToString)			'患者番号
						.setVal(sqlBCP010R010.prmHSP_HISTORY_NO, pRow(sqlBCP010R010.itmHSP_HISTORY_NO).ToString)	'入退院歴番号
						.setVal(sqlBCP010R010.prmWARD_NM, pRow(sqlBCP010R010.itmWARD_RNM).ToString)					'病棟名
						.setVal(sqlBCP010R010.prmMNGSTATUS_NM, pRow(sqlBCP010R010.itmMNGSTATUS_NM).ToString)		'管理状況
					Case clsConst.Enum_LendUnit.Each_Dept		  '科歴単位
						.setVal(sqlBCP010R010.prmDEPT_CD, pRow(sqlBCP010R010.itmDEPT_CD).ToString)					'診療科コード
						.setVal(sqlBCP010R010.prmDEPT_NM, pRow(sqlBCP010R010.itmDEPT_RNM).ToString)					'診療科名
						.setVal(sqlBCP010R010.prmBYOREKI_NO, pRow(sqlBCP010R010.itmBYOREKI_NO).ToString)			'病歴番号
						.setVal(sqlBCP010R010.prmHSP_DT, chkDbDate(pRow(sqlBCP010R010.itmHSP_DT).ToString))			'入院日
						.setVal(sqlBCP010R010.prmOUT_HSP_DT, chkDbDate(pRow(sqlBCP010R010.itmOUT_HSP_DT).ToString))	'退院日

						wrkBarcodeType = clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00092)
						For i As Integer = 0 To wrkBarcodeType.Length - 1
							Select Case wrkBarcodeType.Chars(i)
							Case CST_BARCODE_PATIENT_NO																'患者番号
														wrkBARCODE &= Me.cnvPatientNo(pRow(sqlBCP010R010.itmPATIENT_NO).ToString)
							Case CST_BARCODE_DEPT_CD																'診療科コード
														wrkBARCODE &= pRow(sqlBCP010R010.itmDEPT_CD).ToString
							Case CST_BARCODE_DATE
											Select Case clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00077)
												Case CST_START_DT_FLG												'開始日
													If IsDate(pRow(sqlBCP010R010.itmSTART_DT)) = True Then
														wrkBARCODE &= FormatDateTime(pRow(sqlBCP010R010.itmSTART_DT), DateFormat.ShortDate).Replace("/", "")
													End If
												Case CST_END_DT_FLG													'終了日
													If IsDate(pRow(sqlBCP010R010.itmEND_DT)) = True Then
														wrkBARCODE &= FormatDateTime(pRow(sqlBCP010R010.itmEND_DT), DateFormat.ShortDate).Replace("/", "")
													End If
												Case Else

											End Select
							Case Else

							End Select
						Next
						.setVal(sqlBCP010R010.prmBARCODE, CST_BC_CAR & wrkBARCODE & CST_BC_CAR)						'バーコード
						.setVal(sqlBCP010R010.prmCHECK_FLG, clsConst.Enum_CheckBox_Flg.CheckOn)						'チェック						
						.setVal(sqlBCP010R010.prmPATIENT_NO, pRow(sqlBCP010R010.itmPATIENT_NO).ToString)			'患者番号
						.setVal(sqlBCP010R010.prmHSP_HISTORY_NO, pRow(sqlBCP010R010.itmHSP_HISTORY_NO).ToString)	'入退院歴番号
						.setVal(sqlBCP010R010.prmCH_NO, pRow(sqlBCP010R010.itmCH_NO).ToString)						'科歴番号
						.setVal(sqlBCP010R010.prmWARD_NM, pRow(sqlBCP010R010.itmWARD_RNM).ToString)					'病棟名
						.setVal(sqlBCP010R010.prmMNGSTATUS_NM, pRow(sqlBCP010R010.itmMNGSTATUS_NM).ToString)		'管理状況
					Case Else

				End Select
			End With
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パラメータセット(空白行)
	''' </summary>
	''' <param name="db">クラスMDB</param>
	''' <remarks>
	''' 2010/10/05 新規作成 ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Sub setParm_Space(ByVal db As clsDB)
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "setParm_Space", CST_LOG_PRODUCT, CST_LOG_CLASS, "MDB登録パラメータセット(空白行) START")
		Try
			With db
				' パラメータ値設定
				.setVal(sqlBCP010R010.prmHOST_NM, clsConst.CST_HOST_NM)										'ホストID
				.setVal(sqlBCP010R010.prmPATIENT_ID_V3, vbNullString)										'患者番号
				.setVal(sqlBCP010R010.prmPATIENT_NM, vbNullString)											'氏名
				.setVal(sqlBCP010R010.prmPATIENT_KNM, vbNullString)											'氏名カナ
				.setVal(sqlBCP010R010.prmDEPT_CD, vbNullString)												'診療科コード
				.setVal(sqlBCP010R010.prmDEPT_NM, vbNullString)												'診療科名
				.setVal(sqlBCP010R010.prmGENDER_CD, vbNullString)											'性
				.setVal(sqlBCP010R010.prmBYOREKI_NO, vbNullString)											'病歴番号
				.setVal(sqlBCP010R010.prmHSP_DT, vbNullString)												'入院日
				.setVal(sqlBCP010R010.prmOUT_HSP_DT, vbNullString)											'退院日
				.setVal(sqlBCP010R010.prmREMARKS1, vbNullString)											'備考１
				.setVal(sqlBCP010R010.prmREMARKS2, vbNullString)											'備考２
				.setVal(sqlBCP010R010.prmBARCODE, vbNullString)												'バーコード
				.setVal(sqlBCP010R010.prmCHECK_FLG, vbNullString)											'チェック
				.setVal(sqlBCP010R010.prmPATIENT_NO, vbNullString)											'患者番号
				.setVal(sqlBCP010R010.prmHSP_HISTORY_NO, vbNullString)										'入退院歴番号
				.setVal(sqlBCP010R010.prmCH_NO, vbNullString)												'科歴番号
				.setVal(sqlBCP010R010.prmWARD_CD, vbNullString)												'病棟コード
				.setVal(sqlBCP010R010.prmWARD_NM, vbNullString)												'病棟名
				.setVal(sqlBCP010R010.prmHSP_CNL_CD, vbNullString)											'入院経路コード
				.setVal(sqlBCP010R010.prmHSP_CNL_NM, vbNullString)											'入院経路
				.setVal(sqlBCP010R010.prmOUT_HSP_CNL_CD, vbNullString)										'退院経路コード
				.setVal(sqlBCP010R010.prmOUT_HSP_CNL_NM, vbNullString)										'退院経路
				.setVal(sqlBCP010R010.prmOUT_HSP_OUTCOME_CD, vbNullString)									'退院転帰コード
				.setVal(sqlBCP010R010.prmOUT_HSP_OUTCOME_NM, vbNullString)									'退院転帰
				.setVal(sqlBCP010R010.prmRECORD_MNGSTATUS_CD, vbNullString)									'カルテ管理状況コード
				.setVal(sqlBCP010R010.prmMNGSTATUS_NM, vbNullString)										'管理状況
				.setVal(sqlBCP010R010.prmDSPORDER, vbNullString)											'表示順
				.setVal(sqlBCP010R010.prmLASTUPDUSER_CD, clsSysMst.getLoginId)								'更新者コード
				.setVal(sqlBCP010R010.prmLASTUPD_DT, DateTime.Now())										'更新日
			End With
		Catch ex As Exception
			Throw
		End Try
	End Sub

	''' ---------------------------------------------
	''' <summary>
	''' パラメータ日付チェック
	''' </summary>
	''' <param name="wrkDate">チェックする日付</param>
	''' <remarks>
	''' 2010/11/18 新規作成 ACS)常包<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function chkDbDate(ByVal wrkDate As String) As String
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "chkDbDate", CST_LOG_PRODUCT, CST_LOG_CLASS, "パラメータ日付チェック START")
		Try
			If String.IsNullOrEmpty(wrkDate) = True Then
				Return vbNullString
			Else
				Return FormatDateTime(wrkDate, DateFormat.ShortDate)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Function

	''' ---------------------------------------------
	''' <summary>
	''' 動作環境より取得した患者番号桁数に変換
	''' </summary>
	''' <remarks>
	''' 2011/03/09 新規作成 ACS)仙頭<BR/>
	''' </remarks>
	''' ---------------------------------------------
	Private Function cnvPatientNo(ByVal PatientNo As String) As String
		clsSysMst.logEx(clsSysMst.logLevel.DBG, Me.GetType.Assembly.GetName.Name, Me.GetType.Name, "cnvPatientNo", CST_LOG_PRODUCT, CST_LOG_CLASS, "患者番号を変換 START")
		Const CST_LEN As Integer = 10
		Dim len As Integer = CST_LEN
		Try
			If String.IsNullOrEmpty(PatientNo) = True Then Return PatientNo

			If IsNumeric(clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00091)) = True Then
				len = clsSysMst.ctlEnvData.getEnv(datEnv.Enum_ENV.ENV_00091)
				Select Case len
					Case 1 To CST_LEN
					Case Else : len = CST_LEN
				End Select
			End If
			If PatientNo.Length <= len Then
				Return PatientNo
			Else
				Return PatientNo.Substring(PatientNo.Length - len)
			End If
		Catch ex As Exception
			Throw
		End Try
	End Function
#End Region

End Class
